@@ -1,7 +1,7 @@
 package Config::IOD::Base;
 
-our $DATE = '2016-03-01'; # DATE
-our $VERSION = '0.23'; # VERSION
+our $DATE = '2016-03-11'; # DATE
+our $VERSION = '0.24'; # VERSION
 
 use 5.010001;
 use strict;
@@ -306,8 +306,8 @@ sub _parse_raw_value {
 sub _decode_json {
     my ($self, $val) = @_;
     state $json = do {
-        require JSON;
-        JSON->new->allow_nonref;
+        require JSON::MaybeXS;
+        JSON::MaybeXS->new->allow_nonref;
     };
     my $res;
     eval { $res = $json->decode($val) };
@@ -431,7 +431,7 @@ Config::IOD::Base - Base class for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.23 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2016-03-01.
+This document describes version 0.24 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2016-03-11.
 
 =head1 EXPRESSION
 
